"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _lodash = require("lodash");

var FastaReader = require("biojs-io-fasta");
var ClustalReader = require("biojs-io-clustal");
var GffReader = require("biojs-io-gff");
var xhr = require("xhr");

var FileHelper = function FileHelper(msa) {
  this.msa = msa;
  return this;
};

var funs = { guessFileType: function guessFileType(name) {
    name = name.split(".");
    var fileName = name[name.length(-1)];
    switch (fileName) {
      case "aln":case "clustal":
        return ClustalReader;break;
      case "fasta":
        return FastaReader;break;
      default:
        return FastaReader;
    }
  },

  guessFileFromText: function guessFileFromText(text) {
    if (!(typeof text !== "undefined" && text !== null)) {
      console.warn("invalid file format");
      return ["", "error"];
    }
    if (text.substring(0, 7) === "CLUSTAL") {
      var reader = ClustalReader;
      var type = "seqs";
    } else if (text.substring(0, 1) === ">") {
      reader = FastaReader;
      type = "seqs";
    } else if (text.substring(0, 1) === "(") {
      type = "newick";
    } else {
      reader = GffReader;
      type = "features";
    }
    //console.warn "Unknown format. Contact greenify"
    return [reader, type];
  },

  parseText: function parseText(text) {
    var _guessFileFromText = this.guessFileFromText(text);

    var _guessFileFromText2 = _slicedToArray(_guessFileFromText, 2);

    var reader = _guessFileFromText2[0];
    var type = _guessFileFromText2[1];

    if (type === "seqs") {
      var seqs = reader.parse(text);
      return [seqs, type];
    } else if (type === "features") {
      var features = reader.parseSeqs(text);
      return [features, type];
    } else {
      return [text, type];
    }
  },

  importFiles: function importFiles(files) {
    var _this = this;

    return function () {
      var result = [];
      var end = files.length - 1;
      for (var i = 0; 0 < end ? i <= end : i >= end; 0 < end ? i++ : i--) {
        var file = files[i];
        var reader = new FileReader();
        reader.onload = function (evt) {
          return _this.importFile(evt.target.result);
        };
        result.push(reader.readAsText(file));
      }
      return result;
    }();
  },

  importFile: function importFile(file) {
    var _this2 = this;

    var fileName;

    var _parseText = this.parseText(file);

    var _parseText2 = _slicedToArray(_parseText, 2);

    var objs = _parseText2[0];
    var type = _parseText2[1];

    if (type === "error") {
      return "error";
    }
    if (type === "seqs") {
      this.msa.seqs.reset(objs);
      this.msa.g.config.set("url", "userimport");
      this.msa.g.trigger("url:userImport");
    } else if (type === "features") {
      alert("Support for reading JalView files is limited. Please open a issue on github if you run into troubles");
      this.msa.seqs.addFeatures(objs);
    } else if (type === "newick") {
      console.error("Loading Newick files is experimental. Please open a issue on github if you run into troubles");
      this.msa.u.tree.loadTree(function () {
        return _this2.msa.u.tree.showTree(file);
      });
    }

    return fileName = file.name;
  },

  importURL: function importURL(url, cb) {
    var _this3 = this;

    url = this.msa.u.proxy.corsURL(url);
    this.msa.g.config.set("url", url);
    return xhr({
      url: url,
      timeout: 0
    }, function (err, status, body) {
      if (!err) {
        var res = _this3.importFile(body);
        if (res === "error") {
          return;
        }
        _this3.msa.g.trigger("import:url", url);
        if (cb) {
          return cb();
        }
      } else {
        return console.log(err);
      }
    });
  }
};

(0, _lodash.extend)(FileHelper.prototype, funs);
exports.default = FileHelper;